@@ -71,8 +71,8 @@ class Command(object):
         if isinstance(self.max, Many):
             n -= 1
 
-        if len(split) > 0:
-            for i in range(n):
+        for i in range(n):
+            try:
                 param_cast = split.pop(0)
                 if self.params[i][ParamDictKeyEnum.ANNOTATION] is str:
                     pass
@@ -85,6 +85,8 @@ class Command(object):
                 else:
                     raise NotImplementedError
                 out.append(param_cast)
+            except IndexError:
+                pass
             out.extend(split)
 
         return await self.handler(main, msg, context, *out)
